<?php
/**
 * PEAR_Sniffs_NamingConventions_ValidVariableNameSniff.
 *
 * PHP version 5
 *
 * @category  PHP
 * @package   PHP_CodeSniffer
 * @author    Greg Sherwood <gsherwood@squiz.net>
 * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
 * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
 * @version   CVS: $Id: ValidVariableNameSniff.php,v 1.2 2008/06/13 04:10:43 squiz Exp $
 * @link      http://pear.php.net/package/PHP_CodeSniffer
 */

if (class_exists('PHP_CodeSniffer_Standards_AbstractVariableSniff', true) === false) {
    $error = 'Class PHP_CodeSniffer_Standards_AbstractVariableSniff not found';
    throw new PHP_CodeSniffer_Exception($error);
}

/**
 * PEAR_Sniffs_NamingConventions_ValidVariableNameSniff.
 *
 * Checks the naming of member variables.
 *
 * @category  PHP
 * @package   PHP_CodeSniffer
 * @author    Greg Sherwood <gsherwood@squiz.net>
 * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
 * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
 * @version   Release: 1.2.0a1
 * @link      http://pear.php.net/package/PHP_CodeSniffer
 */
class Borealis_Sniffs_NamingConventions_ValidVariableNameSniff extends PHP_CodeSniffer_Standards_AbstractVariableSniff
{


    /**
     * Processes class member variables.
     *
     * @param PHP_CodeSniffer_File $phpcsFile The file being scanned.
     * @param int                  $stackPtr  The position of the current token
     *                                        in the stack passed in $tokens.
     *
     * @return void
     */
    protected function processMemberVar(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
    {
        $tokens = $phpcsFile->getTokens();

        $memberProps = $phpcsFile->getMemberProperties($stackPtr);
        if (empty($memberProps) === true) {
            return;
        }

        $memberName     = ltrim($tokens[$stackPtr]['content'], '$');
        $isStatic       = $memberProps['is_static'];   
        $isPublic       = ($memberProps['scope'] === 'private') ? false : true;
        
        if (!$isStatic && ($memberName{0} !== 'm' || $memberName{1} !== '_')) 
        {
            $error = "Member variable \"$memberName\" must be prefixed with 'm_'";
            $phpcsFile->addError($error, $stackPtr);
            return;
        }
        
        if ($isStatic && ($memberName{0} !== 's' || $memberName{1} !== '_'))   
        {
            $error = "Static Member variable \"$memberName\" must be prefixed with an underscore";
            $phpcsFile->addError($error, $stackPtr);
            return;
        }
          
        if (!$this->isValidVarName($memberName))
        {
            $error = "Variable \"$memberName\" must be have a valide name";
            $phpcsFile->addError($error, $stackPtr);
            return;       
        }   

    }//end processMemberVar()


    /**
     * Processes normal variables.
     *
     * @param PHP_CodeSniffer_File $phpcsFile The file where this token was found.
     * @param int                  $stackPtr  The position where the token was found.
     *
     * @return void
     */
    protected function processVariable(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
    {
        $tokens  = $phpcsFile->getTokens();
        $varName = ltrim($tokens[$stackPtr]['content'], '$');

        $phpReservedVars = array(
                            '_SERVER',
                            '_GET',
                            '_POST',
                            '_REQUEST',
                            '_SESSION',
                            '_ENV',
                            '_COOKIE',
                            '_FILES',
                            'GLOBALS',
                            'this',
                           );

        // If it's a php reserved var, then its ok.
        if (in_array($varName, $phpReservedVars) === true) {
            return;
        }
        
        if (!$this->isValidVarName($varName))
        {
            $error = "Variable \"$varName\" must be have a valide name";
            $phpcsFile->addError($error, $stackPtr);
            return;       
        }
        
        return;

    }//end processVariable()


    /**
     * Processes variables in double quoted strings.
     *
     * @param PHP_CodeSniffer_File $phpcsFile The file where this token was found.
     * @param int                  $stackPtr  The position where the token was found.
     *
     * @return void
     */
    protected function processVariableInString(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
    {
        // We don't care about normal variables.
        return;

    }//end processVariableInString()


    protected function isValidVarName($pstrVarName)
    {
        if (preg_match('/^(([mgs]?_?)|(p))((b)|(i)|(l)|(f)|(s)|(d)|(c)|(str)|(byte)|(obj))[A-Z][a-zA-Z0-9]+$/', $pstrVarName) === 0) 
        {
            return false;
        }
        return true;   
    }
    
}//end class

?>
