<?php
/**
* Classe qui représente un role du acl   
*
* PHP versions 5
* 
* @category  PHP
* @package   Borealis-acl  
* @author    Pascal Martin 
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.boreal-is.com/license BSD License
* @link      http://www.boreal-is.com
*/

/**
* Classe qui représente un role du acl
* 
* @category   PHP 
* @package    Borealis-acl
* @subpackage Object  
* @author     Pascal Martin 
*/ 
class com_borealis_acl_object_Role extends com_borealis_acl_object_Base
{
    /**
    * Create new Role and return
    * 
    * @param string $pstrName Nom du role
    * 
    * @return com_borealis_acl_object_Role
    */
    public static function create($pstrName)
    {    
        return parent::create('Role', $pstrName);
    }
    
    /**
    * Return role if exist else null
    * 
    * @param string $pstrName Nom du role
    * 
    * @return com_borealis_acl_object_Role
    */
    public static function getByName($pstrName)
    {
        return parent::getByName('Role', $pstrName);               
    }   
    
    /**
    * Return role if exist else null
    * 
    * @param int $piID Indentificateur du role
    * 
    * @return com_borealis_acl_object_Role
    */
    public static function getByID($piID)
    {
        return parent::getByID('Role', $piID);        
    }
    
    /**
    * Return all role
    * 
    * @return ArrayObject of com_borealis_acl_object_Role 
    */
    public static function getAll()
    {
        return parent::getAll('Role');  
    } 
    
    // ----------------------------
    // Custom to this object
    // ----------------------------
    
    /**
    * Add member into this role
    * 
    * @param String $pstrUsername Nom d'utilisateur
    * 
    * @return void
    */
    public function addMember($pstrUsername)
    {
        com_borealis_acl_datastore_DataStoreFactory::getDataStore()->insertRoleMember($this, $pstrUsername);    
    }
    
    /**
    * Delete member into this role
    * 
    * @param String $pstrUsername Nom d'utilisateur
    * 
    * @return void
    */
    public function removeMember($pstrUsername)
    {
        com_borealis_acl_datastore_DataStoreFactory::getDataStore()->deleteRoleMember($this, $pstrUsername);            
    }
    
    /**
    * Return list of member register in this role
    * 
    * @return ArrayObject of Username string
    */
    public function getMember()
    {
        return com_borealis_acl_datastore_DataStoreFactory::getDataStore()->selectRoleMember($this);
    }
    
    /**
    * Add permission into this role
    * 
    * @param com_borealis_acl_object_Ressource $pobjRessource Ressource
    * @param com_borealis_acl_object_Action    $pobjAction    Action
    * 
    * @return void
    */
    public function addPermission(com_borealis_acl_object_Ressource $pobjRessource, com_borealis_acl_object_Action $pobjAction)
    {
        com_borealis_acl_datastore_DataStoreFactory::getDataStore()->insertRolePermission($this, $pobjRessource, $pobjAction);       
    }
    
    /**
    * Remove permission into this role
    * 
    * @param com_borealis_acl_object_Ressource $pobjRessource Ressource
    * @param com_borealis_acl_object_Action    $pobjAction    Action
    * 
    * @return void
    */
    public function removePermission(com_borealis_acl_object_Ressource $pobjRessource, com_borealis_acl_object_Action $pobjAction)
    {
        com_borealis_acl_datastore_DataStoreFactory::getDataStore()->deleteRolePermission($this, $pobjRessource, $pobjAction);        
    }

    /**
    * Return permission list for this role array('action' => action, 'ressource' => ressource, ...)
    *
    * @return ArrayObject
    */
    public function getPermission()
    {
        $objArrayRessource = com_borealis_acl_object_Ressource::getRolePermissionRessource($this);
        $objArrayAction = com_borealis_acl_object_Action::getRolePermissionAction($this);
        $objArrayResult = new ArrayObject();
        
        $objIteratorRessource = $objArrayRessource->getIterator();
        $objIteratorAction = $objArrayAction->getIterator();
        while ($objIteratorRessource->valid() && $objIteratorAction->valid())
        {
            $objArrayResult->append(array('ressource' => $objIteratorRessource->current(), 'action' => $objIteratorAction->current() ));
            $objIteratorRessource->next();
            $objIteratorAction->next(); 
        } 
        
        return $objArrayResult;
    }
}
  
?>
