<?php
/**
* Authentification par alfresco  
*
* PHP versions 5
* 
* @category  PHP
* @package   Borealis-authentication
* @author    Pascal Martin 
* @copyright Boréal Informations Stratégiques Inc.
* @license   http://www.boreal-is.com/license Borealis License
* @link      http://www.boreal-is.com
*/

/**
* Authentification par alfresco
* 
* @category   PHP 
* @package    Borealis-authentication
* @subpackage Checker  
* @author     Pascal Martin 
*/ 
class com_borealis_authentication_checker_AlfrescoChecker extends com_borealis_authentication_checker_Checker
{
    private $m_strURL = null;
    
    /**
    * Constructeur de la classe com_borealis_authentication_checker_AlfrescoChecker 
    * 
    * @param com_borealis_authentication_password_PasswordCreator $pobjPasswordCreator Créateur de mot de passe 
    * @param string                                               $pstrURL             Url du webscript d'authentification d'alfresco    
    * 
    * @return com_borealis_authentication_checker_AlfrescoChecker
    */
    public function __construct(com_borealis_authentication_password_PasswordCreator $pobjPasswordCreator, $pstrURL) 
    {        
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrURL);
        $this->m_strURL = $pstrURL;
        parent::__construct($pobjPasswordCreator);
    }
    
    /**
    * Vérifie le doit d'authentification
    * 
    * @param string $pstrUsername Nom d'utilisateur
    * @param string $pstrPassword Mot de passe
    * 
    * @return boolean Authorized 
    */
    public function isAuthorized($pstrUsername, $pstrPassword)
    {
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrUsername);
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrPassword);
        
        $objArrayData = array('u'=>$pstrUsername, 'pw'=> $this->getPasswordValue($pstrPassword));
        $strUrl = $this->m_strURL."?".http_build_query($objArrayData);
        $strXMLResponse = $this->getUrlContents($strUrl);
        $objSimpleXML = new SimpleXMLElement($strXMLResponse);

        // Validation du login
        $bResult = false;
        if ($objSimpleXML->getName() == 'ticket')
        {       
            if (isset($_SESSION))
            { 
                $_SESSION['ALFRESCO_TICKET'] = (string)$objSimpleXML;            
            }
            $bResult = true;
        }
        else 
        {
            if (isset($_SESSION))
            {
                $_SESSION['ALFRESCO_TICKET_REASON'] = (string)$objSimpleXML->message;         
                unset($_SESSION['ALFRESCO_TICKET']);                                       
            }
        }     
        return $bResult;           
    }
     
    /**
    * Retourne la réponse de l'appele d'une page web
    *      
    * @param string $pstrUrl Adresse de la page
    * 
    * @return string
    */
    private function getUrlContents($pstrUrl)
    {
        $objCrl = curl_init();
        $iTimeout = 2;
        curl_setopt($objCrl, CURLOPT_URL, $pstrUrl);
        curl_setopt($objCrl, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($objCrl, CURLOPT_CONNECTTIMEOUT, $iTimeout);
        $strRet = curl_exec($objCrl);
        curl_close($objCrl);
        return $strRet;
    }
}
  
?>
