<?php
/**
* Récupère les informations de la base de données par le webService    
*
* PHP versions 5
* 
* @category  PHP
* @package   Borealis-authentication
* @author    Charles Villemure
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.boreal-is.com/license BSD License
* @link      http://www.boreal-is.com
*/

/**
* Récupère les informations de la base de données par le webService
* 
* @category   PHP 
* @package    Borealis-authentication
* @subpackage Checker  
* @author     Charles Villemure 
*/ 
class com_borealis_authentication_checker_WebServicesChecker extends com_borealis_authentication_checker_Checker
{
    private $m_strWSDL = null;
    private $m_strConnectionLookup = null;
    private $m_strQuery = null;
    private static $s_strDataTypeString = null;       
    
    /**
    * Constructeur de la classe com_borealis_authentication_checker_WebServicesChecker
    * 
    * @param com_borealis_authentication_password_PasswordCreator $pobjPasswordCreator  Créateur de mot de passe 
    * @param mixed                                                $pstrWsdl             WSDL du webService
    * @param mixed                                                $pstrConnectionLookup ConnectionLookup pour se connecter à la BD
    * @param mixed                                                $pstrQuery            Requête sql pour la récupération des user doit retouné une ou plusieur ligne si l'authentification réussit
    * 
    * @return com_borealis_authentication_checker_WebServicesChecker
    */
    public function __construct(com_borealis_authentication_password_PasswordCreator $pobjPasswordCreator, $pstrWsdl, $pstrConnectionLookup, $pstrQuery) 
    {        
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrWsdl);
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrConnectionLookup);
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrQuery);
        $this->m_strWSDL = $pstrWsdl;
        $this->m_strConnectionLookup = $pstrConnectionLookup;
        $this->m_strQuery = $pstrQuery;
        
        if (self::$s_strDataTypeString == null)
        {
            self::$s_strDataTypeString = $this->getWebServiceMethodReturnValue('getDataTypeString');       
        }
        
        parent::__construct($pobjPasswordCreator);
    }
    
    /**
    * Vérifie le doit d'authentification
    * 
    * @param string $pstrUsername Nom d'utilisateur
    * @param string $pstrPassword Mot de passe
    * 
    * @return boolean Authorized 
    */
    public function isAuthorized($pstrUsername, $pstrPassword)
    {
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrUsername);
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrPassword); 
        
        $objParams = array();                                          
        $this->addParameter(&$objParams, self::$s_strDataTypeString, $pstrUsername);                                      
        $this->addParameter(&$objParams, self::$s_strDataTypeString, $this->getPasswordValue($pstrPassword)); 
        $objResultXML = $this->executePreparedQuery($objParams);
        
        return sizeof($objResultXML) > 0;                 
    }          
    
    /**
    * Execute query statement and throw exception on error
    * 
    * @param mixed $pobjParams Array of parameters to pass to query
    * 
    * @return SimpleXML result from the webService
    */
    private function executePreparedQuery($pobjParams)
    {
        return com_borealis_foundation_util_WebServices::executePreparedQuery($this->m_strWSDL, $this->m_strConnectionLookup, $this->m_strQuery, $pobjParams);
    }           
    
    /**
    * Function to add a parameter (type & value pair) into the parameters array.
    * 
    * @param mixed &$pobjParams    Parameters array
    * @param mixed $pstrParamType  Type of the parameter (known by the WebService)
    * @param mixed $pstrParamValue Value of the parameter
    * 
    * @return void
    */
    private function addParameter(&$pobjParams, $pstrParamType, $pstrParamValue)
    {
        com_borealis_foundation_util_WebServices::addPreparedStatementParameter($pobjParams, $pstrParamType, $pstrParamValue);
    }
    
    /**
    * Appelle une méthode du webService et retourne la valeur string du return 
    * 
    * @param mixed $pstrMethodName   Nom de la méthode a appeler
    * @param mixed $pobjMethodParams Array de paramètres à passer à la méthode
    * 
    * @return object result from the webService 
    */
    private function getWebServiceMethodReturnValue($pstrMethodName, $pobjMethodParams = null)
    {
        return com_borealis_foundation_util_WebServices::getWebServiceMethodReturnValue($this->m_strWSDL, $pstrMethodName, $pobjMethodParams);
    }
}
  
?>
