<?php
/**
* Récupère les informations d'un serveur ldap
*
* PHP versions 5
* 
* @category  PHP
* @package   Borealis-users  
* @author    Pascal Martin 
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.boreal-is.com/license BSD License
* @link      http://www.boreal-is.com
*/

/**
* Récupère les informations d'un serveur ldap        
* 
* @category   PHP 
* @package    Borealis-users
* @subpackage DataStore  
* @author     Pascal Martin 
*/ 
class com_borealis_users_datastore_LDAPDataStore implements com_borealis_users_datastore_DataStore
{
    private $m_strHostname = null; 
    private $m_iPort = null; 
    private $m_strBindDN = null; 
    private $m_strPassord = null; 
    private $m_strSearchDN = null; 
    private $m_strSearchFilter = null; 
    private $m_strNameColumn = null; 
    private $m_strUsernameColumn = null;
    private $m_objArrayOptions = array();
    
    private $m_objArrayUsers = null;
    
    /**
    * Constructeur de la classe com_borealis_users_datastore_LDAPDataStore
    * 
    * @param string $pstrHostname       Adresse du serveur ldap
    * @param string $piPort             Port du serveur ldap
    * @param string $pstrBindDN         Distinguished Name de user de connexion, null pour acces anonyme 
    * @param string $pstrPassord        Mot de passe pour la connexion, null pour acces anonyme
    * @param string $pstrSearchDN       Distinguished Name des object a rechercher
    * @param string $pstrSearchFilter   Filtre pour la recherche
    * @param string $pstrNameColumn     Nom de l'attribut qui contien le nom de l'utilisateur
    * @param string $pstrUsernameColumn Nom de l'attribut qui contien le nom d'utilisateur (login name)
    * @param array  $pobjArrayOptions   Option suplémentaire pour la connexion ldap
    * 
    * @return com_borealis_users_datastore_LDAPDataStore
    */
    public function __construct($pstrHostname, $piPort, $pstrBindDN, $pstrPassord, $pstrSearchDN, $pstrSearchFilter, $pstrNameColumn, $pstrUsernameColumn, array $pobjArrayOptions) 
    {        
        $this->m_strHostname = $pstrHostname;  
        $this->m_iPort = $piPort; 
        $this->m_strBindDN = $pstrBindDN; 
        $this->m_strPassord = $pstrPassord; 
        $this->m_strSearchDN = $pstrSearchDN; 
        $this->m_strSearchFilter = $pstrSearchFilter; 
        $this->m_strNameColumn = $pstrNameColumn; 
        $this->m_strUsernameColumn = $pstrUsernameColumn;
        $this->m_objArrayOptions = $pobjArrayOptions;
        
        $this->fill();
    }
    
    /**
    * Chargement de utilisateur de la source de donnée
    * 
    * @return void
    */
    public function fill()
    {
        $this->m_objArrayUsers = array();

        $objLDAPConnect=ldap_connect($this->m_strHostname, $this->m_iPort);
       
        foreach ($this->m_objArrayOptions as $piOption => $objValue)
        {
            ldap_set_option($objLDAPConnect, $piOption, $objValue);
        }
        
        ldap_bind($objLDAPConnect, $this->m_strBindDN, $this->m_strPassord);  
        $objSearchResult=ldap_search($objLDAPConnect, $this->m_strSearchDN, $this->m_strSearchFilter);  
        $objInfo = ldap_get_entries($objLDAPConnect, $objSearchResult);
        ldap_close($objLDAPConnect);
        
        for ($iIterator=0; $iIterator<$objInfo["count"]; ++$iIterator) 
        {
            $strName = (string)$objInfo[$iIterator][$this->m_strNameColumn][0];
            $strUsername = (string)$objInfo[$iIterator][$this->m_strUsernameColumn][0]; 
            $strName = mb_convert_encoding($strName, 'ISO-8859-1', mb_detect_encoding($strName)); 
            $this->m_objArrayUsers[] = new com_borealis_users_User($strName, $strUsername);
        }         
    }
    
    /**
    * Retourne la liste de utilisateur de la soruce de donnée
    * 
    * @return array
    */
    public function getUsers()
    {
        return $this->m_objArrayUsers;         
    } 
    
}

?>