<?xml version="1.0" encoding="utf-8"?>
<!-- 
   Copyright (c) 2011- Mapgears Inc., published under the BSD license.
   See http://geoprisma.org/license for the full text of the license.
 --> 

<xsl:stylesheet version="1.0" xmlns:php="http://php.net/xsl"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:dyn="http://exslt.org/dynamic"
    xmlns:editfeature_split="http://geoprisma.org/editfeature_split"
    extension-element-prefixes="dyn">
  <xsl:namespace-alias stylesheet-prefix="php" result-prefix="xsl" />

  <xsl:template name="editfeature_split:printWidgetSource">
    <xsl:variable name="WidgetType">
      <xsl:text>editfeature_split</xsl:text>
    </xsl:variable>

    <!-- OpenLayers temp overrides to support polygon spliting -->
    <script>
      <xsl:attribute name="src" >
        <xsl:value-of select="$g_widgets_url"/>
        <xsl:text>/editfeature/split/lib/OpenLayers/Geometry.js</xsl:text>
      </xsl:attribute>
    </script>
    <script>
      <xsl:attribute name="src" >
        <xsl:value-of select="$g_widgets_url"/>
        <xsl:text>/editfeature/split/lib/OpenLayers/Geometry/Polygon.js</xsl:text>
      </xsl:attribute>
    </script>
    <script>
      <xsl:attribute name="src" >
        <xsl:value-of select="$g_widgets_url"/>
        <xsl:text>/editfeature/split/lib/OpenLayers/Control/Split.js</xsl:text>
      </xsl:attribute>
    </script>

    <!-- Superclass JS file of the widget.
         TODO: should be included only once
      -->
    <script>
      <xsl:attribute name="src" >
        <xsl:value-of select="$g_widgets_url"/>
        <xsl:text>/editfeature/EditFeature.js</xsl:text>
      </xsl:attribute>
    </script>

    <script>
      <xsl:attribute name="src" >
        <xsl:value-of select="$g_widgets_url"/>
        <xsl:text>/editfeature/split/lib/OpenLayers/Control/EditFeature_Split.js</xsl:text>
      </xsl:attribute>
    </script>

    <!-- i18n -->
    <xsl:if test="$g_locale = 'fr_CA'">
      <script>
        <xsl:attribute name="src" >
          <xsl:value-of select="$g_widgets_url"/>
          <xsl:text>/editfeature/split/resources/lang/fr.js</xsl:text>
        </xsl:attribute>
      </script>
    </xsl:if>

    <script type="text/javascript">
      if (!Ext.isDefined(goEditFeatureActions)) {
          var goEditFeatureActions = {};
      }
    </script>

  </xsl:template>

  <xsl:template name="editfeature_split:printWidgetExecution">
    <xsl:param name="pWidgetName" />
    <xsl:param name="pMapName" />

    <xsl:variable name="WidgetType">
      <xsl:text>editfeature_split</xsl:text>
    </xsl:variable>

    <!-- This widget supports this servicetype only-->
    <xsl:variable name="pServiceType">
      <xsl:text>featureserver</xsl:text>
    </xsl:variable>

    <script type="text/javascript">
      <!-- Quick reference to the Map object -->
      oMap = objGPWidget<xsl:value-of select="$pMapName"/>;

      var options, defaultOptions, action;
      
      defaultOptions =
      <xsl:for-each select="./options">
        <xsl:call-template name="getObjectFromNode">
          <xsl:with-param name="pNode" select="." />
        </xsl:call-template>
      </xsl:for-each>;

      <!-- splitWindow option, used below -->
      <xsl:variable name="splitWindow">
        <xsl:if test="./options/splitWindow">
          delete options.splitWindow;
          if (window.<xsl:value-of select="./options/splitWindow" />) {
              options.splitWindow = window.<xsl:value-of select="./options/splitWindow" />;
          }
        </xsl:if>
      </xsl:variable>

      <xsl:for-each select="./resources/resource">

        <!-- ResourceName -->
        <xsl:variable name="pResourceName">
          <xsl:value-of select="." />
        </xsl:variable>

        <!-- Use the DataStoreName to validate that the resource has a valid
             service type
          -->
        <!-- DataStoreName -->
        <xsl:variable name="pDataStoreName">
          <xsl:call-template name="getDataStoreInfoFromWidget">
            <xsl:with-param name="pWidgetName" select="$pWidgetName" />
            <xsl:with-param name="pServiceType" select="$pServiceType" />
            <xsl:with-param name="pNodeName"><xsl:text>name</xsl:text></xsl:with-param>
            <xsl:with-param name="pResourceName" select="$pResourceName"/>
          </xsl:call-template>
        </xsl:variable>

        <xsl:if test="$pDataStoreName!=''">
          <!-- get resource 'iconClsSplit' option, if any -->
          <xsl:variable name="iconClsSplit">
            <xsl:value-of select="/geoprisma/resources/resource[./name = $pResourceName]/options/iconClsSplit"/>
          </xsl:variable>

          <!-- get resource 'tooltipTextSplit' option, i18n supported -->
          <xsl:variable name="tooltipTextSplit">
            <xsl:for-each select="/geoprisma/resources/resource[./name = $pResourceName]/options/tooltipTextSplit"><xsl:call-template name="getText" /></xsl:for-each>
          </xsl:variable>

          var actionId = Ext.id();
          var options = Ext.applyIf({
              'resource': '<xsl:value-of select="$pResourceName" />',
              'id': actionId
          }, defaultOptions);

          <xsl:if test="$splitWindow != ''">
            <xsl:value-of select="$splitWindow" />
          </xsl:if>

          <!-- Widget object creation  -->
          var objGPWidget<xsl:value-of select="$pWidgetName" /><xsl:value-of select="$pResourceName" /> = new OpenLayers.Control.EditFeature_Split(options);

          <!-- GeoExt.Action object for the geoexttoolbar-->
          action = new GeoExt.Action({
            id: actionId,
          <xsl:choose>
            <xsl:when test="$iconClsSplit != ''">
            iconCls: '<xsl:value-of select="$iconClsSplit" />',
	    </xsl:when>
	    <xsl:otherwise>
            iconCls: 'editfeature_split',
	    </xsl:otherwise>
	  </xsl:choose>
            control: objGPWidget<xsl:value-of select="$pWidgetName" /><xsl:value-of select="$pResourceName" />,
            map: oMap,
            // button options
            toggleGroup: oMap.id,
            allowDepress: false,
          <xsl:choose>
            <xsl:when test="$tooltipTextSplit != ''">
            tooltip: <xsl:value-of select="$tooltipTextSplit" />,
	    </xsl:when>
	    <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="$g_locale = 'fr_CA'">
            tooltip: "Outil de division de géométrie",
	        </xsl:when>
	        <xsl:otherwise>
            tooltip: "Geometry splitting widget",
                </xsl:otherwise>
              </xsl:choose>
	    </xsl:otherwise>
	  </xsl:choose>
            // check item options
            group: oMap.id
          });

          <!-- Push action in goEditFeatureActions['resource'] array  -->
          if (!goEditFeatureActions['<xsl:value-of select="$pResourceName" />'])
          {
              goEditFeatureActions['<xsl:value-of select="$pResourceName" />'] = [];
          }
          goEditFeatureActions['<xsl:value-of select="$pResourceName" />'].push(action);

        </xsl:if>
      </xsl:for-each>
    </script>

    <script type="text/javascript">
    </script>
  </xsl:template>

</xsl:stylesheet>
