<?xml version="1.0" encoding="utf-8"?>
<!-- 
   Copyright (c) 2009- Boreal - Information Strategies, published under the BSD license.
   See http://geoprisma.org/license for the full text of the license.
 --> 
<xsl:stylesheet version="1.0" xmlns:php="http://php.net/xsl"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:dyn="http://exslt.org/dynamic"
    xmlns:shortcut="http://geoprisma.org/shortcut"
    extension-element-prefixes="dyn">

  <xsl:output method="html" indent="yes" encoding="utf-8" omit-xml-declaration="yes"/>
  <xsl:namespace-alias stylesheet-prefix="php" result-prefix="xsl" />

<!-- 
     Function : printWidgetSource

     Print the source code for this widget
-->
  <!-- Call for each widget type-->
  <xsl:template name="shortcut:printWidgetSource">
    <xsl:variable name="WidgetType">
      <xsl:text>shortcut</xsl:text>
    </xsl:variable>

    <script>
        <xsl:attribute name="src" >
             <xsl:value-of select="$g_widgets_url"/>
             <xsl:text>/shortcut/lib/org.GeoPrisma.Shortcut.js</xsl:text>
        </xsl:attribute>    
    </script>
    
        <!-- Traduction (utilisation de la méthode extjs)
                http://extjs.com/learn/Tutorial:Localizing_Ext#Application_Localization
        --> 
    <script>            
        Ext.apply(org.GeoPrisma.Shortcut.prototype, {
            emptyText        : <xsl:value-of select="php:functionString('Shortcut::getText','i18n_emptyText','JS')" />,        
            i18n_please_wait : <xsl:value-of select="php:functionString('Shortcut::getText','i18n_please_wait','JS')" />
        });   
    </script>  

    <!-- nWidgets - the number of widgets of THIS type in config -->
    <xsl:variable name="nWidgets">
      <xsl:call-template name="getNumWidgetsByType">
        <xsl:with-param name="pWidgetType" select="$WidgetType" />
      </xsl:call-template>
    </xsl:variable>

    <!-- bMultiple - true if more than ONE widget AND if ONE widet + more than 
         ONE resource using this widget
      -->
    <xsl:variable name="bMultiple">
      <xsl:choose>
        <xsl:when test="$nWidgets > 1">true</xsl:when>
	<xsl:otherwise><xsl:if test="count(../../widgets/widget[./type = $WidgetType]/resources/resource) > 1">true</xsl:if></xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <script type="text/javascript">
      <xsl:if test="$bMultiple = 'true'">
        var objGPWidget<xsl:value-of select="$WidgetType" />GeoExtToolbarOptions = [];
      </xsl:if>

      objGPWidget<xsl:value-of select="$WidgetType" />FormPanel = {
          layout: 'form',
          title: <xsl:value-of select="php:functionString('Shortcut::getText','i18n_panel_title','JS')" />,
          border: false,
          labelAlign: 'top',
          bodyStyle:'padding:5px 5px 0',
          items: []
      };
    </script>

   </xsl:template>

<!-- 
     Function : printWidgetExecution

     Print the execution code for this widget
-->
  <!-- Call for each widget name-->
  <xsl:template name="shortcut:printWidgetExecution">
    <xsl:param name="pWidgetName" />
    <xsl:param name="pMapName" />

    <xsl:variable name="WidgetType">
      <xsl:text>shortcut</xsl:text>
    </xsl:variable>

    <!-- nWidgets - the number of widgets of THIS type in config -->
    <xsl:variable name="nWidgets">
      <xsl:call-template name="getNumWidgetsByType">
        <xsl:with-param name="pWidgetType" select="$WidgetType" />
      </xsl:call-template>
    </xsl:variable>

    <!-- bMultiple
         - true if more than ONE widget
         - true if one widget AND more than ONE resource using this widget
      -->
    <xsl:variable name="bMultiple">
      <xsl:choose>
        <xsl:when test="$nWidgets > 1">true</xsl:when>
	<xsl:otherwise><xsl:if test="count(./resources/resource) > 1">true</xsl:if></xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <!-- ServiceTypes supported by this widget -->
    <xsl:variable name="pFSServiceType">
      <xsl:text>featureserver</xsl:text>
    </xsl:variable>
    <xsl:variable name="pWFSServiceType">
      <xsl:text>wfs</xsl:text>
    </xsl:variable>

    <!-- get draw mode  -->
    <xsl:variable name="pDrawMode">
      <xsl:value-of select="$drawmode" />
    </xsl:variable>

    <!-- Proxy URL -->
    <xsl:variable name="pProxyURL">
      <xsl:value-of select="$proxyurl" />
    </xsl:variable>

    <!-- Proxy URL -->
    <xsl:variable name="pField">
      <xsl:value-of select="./options/field" />
    </xsl:variable>

    <!-- javascript START -->
    <script type="text/javascript">
      <!-- Quick reference to the Map object -->
      oMap = objGPWidget<xsl:value-of select="$pMapName"/>;

      <!-- widget OPTIONS object used to create the widget object -->
      var objWidgetOptions;

      <!--ToolbarOptions for WIDGET. Used if nWidgets = 1 -->
      var objGPWidget<xsl:value-of select="$pWidgetName" />GeoExtToolbarOptions;

      <xsl:for-each select="./resources/resource">
        <!-- ResourceName -->
        <xsl:variable name="pResourceName">
          <xsl:value-of select="." />
        </xsl:variable>

        <!-- Use the DataStoreName to validate that the resource has a valid
             service type, either 'featureserver' or 'wfs'
          -->
        <xsl:variable name="pFSDataStoreName">
          <xsl:call-template name="getDataStoreInfoFromWidget">
            <xsl:with-param name="pWidgetName" select="$pWidgetName" />
            <xsl:with-param name="pServiceType" select="$pFSServiceType" />
            <xsl:with-param name="pNodeName"><xsl:text>name</xsl:text></xsl:with-param>
            <xsl:with-param name="pResourceName" select="$pResourceName"/>
          </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="pWFSDataStoreName">
          <xsl:call-template name="getDataStoreInfoFromWidget">
            <xsl:with-param name="pWidgetName" select="$pWidgetName" />
            <xsl:with-param name="pServiceType" select="$pWFSServiceType" />
            <xsl:with-param name="pNodeName"><xsl:text>name</xsl:text></xsl:with-param>
            <xsl:with-param name="pResourceName" select="$pResourceName"/>
          </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="pDataStoreName">
          <xsl:choose>
            <xsl:when test="$pFSDataStoreName != ''">
              <xsl:value-of select="$pFSDataStoreName" />
	    </xsl:when>
	    <xsl:otherwise>
              <xsl:value-of select="$pWFSDataStoreName" />
	    </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>

        <!-- If a DataStoreName was returned, that means the resource has
             a valid service type.
          -->
        <xsl:if test="$pDataStoreName!=''">

          <!-- ServiceType -->
          <xsl:variable name="pServiceType">
            <xsl:choose>
              <xsl:when test="$pFSDataStoreName != ''">
                <xsl:value-of select="$pFSServiceType" />
	      </xsl:when>
	      <xsl:otherwise>
                <xsl:value-of select="$pWFSServiceType" />
	      </xsl:otherwise>
            </xsl:choose>
          </xsl:variable>

          <!-- Resource Title -->
          <xsl:variable name="resourceTitle">
            <xsl:for-each select="/geoprisma/resources/resource[./name = $pResourceName]/title">
              <xsl:call-template name="getText" />
            </xsl:for-each>
          </xsl:variable>

          <!-- Resource field title -->
          <xsl:variable name="resourceFieldTitle">
            <xsl:for-each select="/geoprisma/resources/resource[./name = $pResourceName]/fields/field[./name = $pField]/title">
              <xsl:call-template name="getText" />
            </xsl:for-each>
          </xsl:variable>

          <!-- ServiceName -->
          <xsl:variable name="pServiceName">
            <xsl:call-template name="getDataStoreInfoFromWidget">
              <xsl:with-param name="pWidgetName" select="$pWidgetName" />
              <xsl:with-param name="pServiceType" select="$pServiceType" />
              <xsl:with-param name="pNodeName"><xsl:text>service</xsl:text></xsl:with-param>
              <xsl:with-param name="pResourceName" select="$pResourceName" />
            </xsl:call-template>
          </xsl:variable>

          <!-- LayerName -->
          <xsl:variable name="pLayerName">
            <xsl:call-template name="getDataStoreInfoFromWidget">
              <xsl:with-param name="pWidgetName" select="$pWidgetName" />
              <xsl:with-param name="pServiceType" select="$pServiceType" />
              <xsl:with-param name="pNodeName"><xsl:text>params/layers</xsl:text></xsl:with-param>
              <xsl:with-param name="pResourceName" select="$pResourceName" />
            </xsl:call-template>
          </xsl:variable>

          <!-- DataStoreText -->
          <xsl:variable name="pDataStoreText">
            <xsl:call-template name="getDataStoreInfoFromWidget">
              <xsl:with-param name="pWidgetName" select="$pWidgetName" />
              <xsl:with-param name="pServiceType" select="$pServiceType" />
              <xsl:with-param name="pNodeName"><xsl:text>params/text</xsl:text></xsl:with-param>
              <xsl:with-param name="pResourceName" select="$pResourceName"/>
            </xsl:call-template>
          </xsl:variable>

          <!-- DataStoreText -->
          <xsl:variable name="pDataStoreFieldText">
            <xsl:for-each select="//geoprisma/datastores/datastore[./name = $pDataStoreName]/params/fields/field[./name = $pField]/text" ><xsl:call-template name="getText" /></xsl:for-each>
          </xsl:variable>

          objWidgetOptions =
          <xsl:for-each select="../../options">
            <xsl:call-template name="getObjectFromNode">
              <xsl:with-param name="pNode" select="." />
            </xsl:call-template>
          </xsl:for-each>;

          objWidgetOptions['resource'] = '<xsl:value-of select="$pResourceName" />';
          objWidgetOptions['id'] = '<xsl:value-of select="$pWidgetName" /><xsl:value-of select="$pResourceName" />';
          objWidgetOptions['url'] = '<xsl:value-of select="$pProxyURL" />';
          objWidgetOptions['layerName'] = '<xsl:value-of select="$pLayerName" />';
          objWidgetOptions['serviceName'] = '<xsl:value-of select="$pServiceName" />';
          objWidgetOptions['resourceName'] = '<xsl:value-of select="$pResourceName" />';
          objWidgetOptions['map'] = oMap;
          objWidgetOptions['serviceType'] = '<xsl:value-of select="$pServiceType" />';


          <!-- 'emptyText'
               check the 'text' property in :
               1) the widget options/text
               2) the datastore params/text
               if none was provided, use the resource name instead

               finally, add te DataStoreFieldText if any
            -->
          var strEmptyText =
          <xsl:choose>
            <xsl:when test="../../options/emptyText">
              <xsl:for-each select="../../options/emptyText" ><xsl:call-template name="getText" /></xsl:for-each>
	    </xsl:when>
	    <xsl:otherwise>
              <xsl:choose>

                <!-- check for a resource title and a resource field title -->
                <xsl:when test="$resourceTitle != ''">
                  <xsl:value-of select="$resourceTitle"/>
                  <xsl:if test="$resourceFieldTitle != ''">
                    + ' (' + <xsl:value-of select="$resourceFieldTitle"/> + ')'
                  </xsl:if>
	        </xsl:when>

                <!-- check for a datastore title and a datastore field title -->
                <xsl:when test="$pDataStoreText != ''">
                  <xsl:value-of select="$pDataStoreText"/> + ' ' + <xsl:value-of select="php:functionString('Shortcut::getText','i18n_shortcut','JS')" />
                  <xsl:if test="$pDataStoreFieldText != ''">
                    +' '+ <xsl:value-of select="php:functionString('Shortcut::getText','i18n_by','JS')" /> +' ' + <xsl:value-of select="$pDataStoreFieldText"/>
                  </xsl:if>
	        </xsl:when>

                <!-- otherwise, use the resource name -->
	        <xsl:otherwise>
                  '<xsl:value-of select="$pResourceName"/> ' + <xsl:value-of select="php:functionString('Shortcut::getText','i18n_shortcut','JS')" />
	        </xsl:otherwise>

	      </xsl:choose>


	    </xsl:otherwise>
	  </xsl:choose>;
          objWidgetOptions['emptyTextAfterLoading'] = strEmptyText;

          <!-- 'fieldLabel'
               check the 'text' property in :
               1) the widget options/text
               2) the datastore params/text
               if none was provided, use the resource name instead

               finally, add te DataStoreFieldText if any
            -->
          var strFieldLabel =
          <xsl:choose>
            <xsl:when test="../../options/fieldLabel">
              <xsl:for-each select="../../options/fieldLabel" ><xsl:call-template name="getText" /></xsl:for-each>
	    </xsl:when>
	    <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="$pDataStoreText != ''">
                  <xsl:value-of select="$pDataStoreText"/> + ' ' + <xsl:value-of select="php:functionString('Shortcut::getText','i18n_shortcut','JS')" />
	        </xsl:when>
	        <xsl:otherwise>
                  '<xsl:value-of select="$pResourceName"/> ' + <xsl:value-of select="php:functionString('Shortcut::getText','i18n_shortcut','JS')" />
	        </xsl:otherwise>
	      </xsl:choose>
              <xsl:if test="$pDataStoreFieldText != ''">
                +' '+<xsl:value-of select="php:functionString('Shortcut::getText','i18n_by','JS')" />+' ' + <xsl:value-of select="$pDataStoreFieldText"/>
              </xsl:if>
	    </xsl:otherwise>
	  </xsl:choose>;
          objWidgetOptions['fieldLabel'] = strFieldLabel;

          <!-- Widget object creation  -->
          var objGPWidget<xsl:value-of select="$pWidgetName" /> = new org.GeoPrisma.Shortcut(objWidgetOptions);

          <!--
              This widget has 2 ways to be drawns :
              - in the GeoExtToolbar
              - in a standard panel
            -->

          <!-- GeoExtToolbar support -->
          <xsl:choose>
            <xsl:when test="$bMultiple = 'true'">
              objGPWidget<xsl:value-of select="$WidgetType" />GeoExtToolbarOptions.push(objGPWidget<xsl:value-of select="$pWidgetName" />);
	    </xsl:when>
	    <xsl:otherwise>
              objGPWidget<xsl:value-of select="$pWidgetName" />GeoExtToolbarOptions = objGPWidget<xsl:value-of select="$pWidgetName" />;
	    </xsl:otherwise>
	  </xsl:choose>

          <!-- FormPanel support  -->
          objGPWidget<xsl:value-of select="$WidgetType" />FormPanel.items.push(objGPWidget<xsl:value-of select="$pWidgetName" />);

        </xsl:if>
      </xsl:for-each><!-- end of for-each resources -->

    </script>
    <!-- javascript END -->
  </xsl:template>

<!-- 
     Function : drawWidget

     Output the widget depending on the render type
-->
  <!-- Call for each widget name -->
  <xsl:template name="shortcut:drawWidget">
    <xsl:param name="pWidgetName" />
      objGPWidget<xsl:value-of select="$pWidgetName" />
  </xsl:template>

<!-- 
     Function : drawWidgets

     Output the widget depending on the render type
-->
  <!-- Call for each widget name -->
  <xsl:template name="shortcut:drawWidgets">
    <xsl:param name="pContainer" />

    <xsl:variable name="WidgetType">
      <xsl:text>shortcut</xsl:text>
    </xsl:variable>

	if (typeof(objGPWidget<xsl:value-of select="$WidgetType" />FormPanel) != 'undefined' &amp;&amp; typeof(<xsl:value-of select="$pContainer" />) != 'undefined')
    {
        if(<xsl:value-of select="$pContainer" />['ctype']){
            <xsl:value-of select="$pContainer" />.add(
                objGPWidget<xsl:value-of select="$WidgetType" />FormPanel
            );
        } else {
            <xsl:value-of select="$pContainer" />.items.push(
                objGPWidget<xsl:value-of select="$WidgetType" />FormPanel
            )
        }
    }
  </xsl:template>

<!--
    Function: getWidgetDepedencies

    Return the list of dependencies for this widget
-->
  <!-- Call for each widget type-->
  <xsl:template name="shortcut:getWidgetDepedencies">

  </xsl:template>

</xsl:stylesheet>
