<?xml version="1.0" encoding="utf-8"?>
<!--
   Copyright (c) 2009- Boreal - Information Strategies, published under the BSD license.
   See http://geoprisma.org/license for the full text of the license.
 -->
<xsl:stylesheet version="1.0" xmlns:php="http://php.net/xsl"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:dyn="http://exslt.org/dynamic"
    xmlns:templatepopup="http://geoprisma.org/templatepopup"
    extension-element-prefixes="dyn">

  <xsl:output method="html" indent="yes" encoding="utf-8" omit-xml-declaration="yes"/>
  <xsl:namespace-alias stylesheet-prefix="php" result-prefix="xsl" />

  <!-- printWidgetSource START  -->
  <xsl:template name="templatepopup:printWidgetSource">
    <xsl:variable name="WidgetType">
      <xsl:text>templatepopup</xsl:text>
    </xsl:variable>
    <script>
        <xsl:attribute name="src" >
             <xsl:value-of select="$g_widgets_url"/>
             <xsl:text>/templatepopup/TemplatePopupWMSGetFeatureInfo.js</xsl:text>
        </xsl:attribute>
    </script>
    <script>
        <xsl:attribute name="src" >
             <xsl:value-of select="$g_widgets_url"/>
             <xsl:text>/templatepopup/TemplatePopup.js</xsl:text>
        </xsl:attribute>
        var objGPWidget<xsl:value-of select="$WidgetType" />GeoExtToolbarOptions;
    </script>
   </xsl:template>
  <!-- printWidgetSource END  -->

  <!-- printWidgetExecution START  -->
  <xsl:template name="templatepopup:printWidgetExecution">
    <xsl:param name="pWidgetName" />
    <xsl:param name="pMapName" />

    <!-- get draw mode  -->
    <xsl:variable name="pDrawMode">
      <xsl:value-of select="$drawmode" />
    </xsl:variable>
    <xsl:variable name="WidgetType">
      <xsl:text>templatepopup</xsl:text>
    </xsl:variable>

    <script type="text/javascript">
      //Ext.onReady(function() {
      var templates = [];
      var layers = [];
      var osmresource = [];
      var resourceParams = [];
      var hasTemplate = false;

      <!-- Loop through all resources -->
      <xsl:for-each select="./resources/resource">
        <!-- Resource Name -->
        <xsl:variable name="resourceName">
          <xsl:value-of select="." />
        </xsl:variable>
        
        <xsl:variable name="resourceTemplate">
          <xsl:for-each select="/geoprisma/resources/resource[./name = $resourceName]/options/templatepopup">
            <xsl:call-template name="getText" />    <!-- Used to escape HTML -->
          </xsl:for-each>
        </xsl:variable>

        <xsl:variable name="layerService">
            <xsl:call-template name="getDataStoreInfoFromWidget">
              <xsl:with-param name="pWidgetName" select="$pWidgetName" />
              <xsl:with-param name="pServiceType"><xsl:text>wms</xsl:text></xsl:with-param>
              <xsl:with-param name="pNodeName"><xsl:text>service</xsl:text></xsl:with-param>
              <xsl:with-param name="pResourceName" select="$resourceName"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:if test="$layerService = ../../options/serviceName">
          <xsl:if test="$resourceTemplate != ''">

            var templatePopupLayers = objGPWidget<xsl:value-of select='$pMapName'/>.getLayersByResource('<xsl:value-of select="$resourceName" />', 'wms');
            var templatePopup = <xsl:value-of select="$resourceTemplate" />;
            
            osmresource.push('<xsl:value-of select="$resourceName" />');
            resourceParams.push("&amp;osmresource[]=<xsl:value-of select="$resourceName" />");

            var tmplLayer;
            var tmplLayerName = '';

            for(var i = 0; i &lt; templatePopupLayers.length; i++)
            {
                <xsl:variable name="layerParams">
                    <xsl:call-template name="getDataStoreInfoFromWidget">
                      <xsl:with-param name="pWidgetName" select="$pWidgetName" />
                      <xsl:with-param name="pServiceType"><xsl:text>wms</xsl:text></xsl:with-param>
                      <xsl:with-param name="pNodeName"><xsl:text>params/layers</xsl:text></xsl:with-param>
                      <xsl:with-param name="pResourceName" select="$resourceName"/>
                    </xsl:call-template>
                </xsl:variable>

                <xsl:if test="$layerParams != ''">
                    tmplLayer = templatePopupLayers[i];
                    tmplLayerName = '<xsl:value-of select="$layerParams" />';
                    layers.push(tmplLayer);
                </xsl:if>
            }

            if(templatePopupLayers &amp;&amp; tmplLayerName &amp;&amp; templatePopup)
            {
                hasTemplate = true;
                templates[tmplLayerName] = templatePopup;
            }

          </xsl:if>
        </xsl:if>
      </xsl:for-each>

       var configOptions =
      <xsl:for-each select="./options">
        <xsl:call-template name="getObjectFromNode">
          <xsl:with-param name="pNode" select="." />
        </xsl:call-template>
      </xsl:for-each>;

      var defaultConfigOptions = {
          autoDetectLayer: false,
          allowDepress: false,
          mode: 'wms'
      };

      if(hasTemplate)
      {
          <xsl:variable name="serviceType">
              <xsl:value-of select="/geoprisma/services/service[./name = ./options/serviceName]/type" />
          </xsl:variable>

          templates['default'] = 'No Template available';

          configOptions = Ext.applyIf(configOptions, defaultConfigOptions);
          configOptions = Ext.applyIf({
            <xsl:choose>
              <xsl:when test="./options/iconCls">
                iconCls: '<xsl:value-of select="./options/iconCls" />',
              </xsl:when>
              <xsl:otherwise>
                text: '<xsl:value-of select='./options/title'/>',
              </xsl:otherwise>
            </xsl:choose>

              mode: '<xsl:value-of select='$serviceType'/>',
              map: objGPWidget<xsl:value-of select='$pMapName'/>,
              tpl: templates,
              layers: layers,
              url: '<xsl:value-of select="$proxyurl" />?osmservice=<xsl:value-of select="./options/serviceName" />'+resourceParams.join(''),

              toggleGroup: objGPWidget<xsl:value-of select='$pMapName'/>.id,
              tooltip: '<xsl:value-of select='./options/title'/>',
              group: objGPWidget<xsl:value-of select='$pMapName'/>.id
          }, configOptions);

          var customBubble = new GeoExt.TemplatePopup(configOptions);

            <xsl:choose>
              <xsl:when test="./options/autoEnable">
                // Do not add the button if autoEnable
              </xsl:when>
              <xsl:otherwise>
                var objGPWidget<xsl:value-of select="$WidgetType" />GeoExtToolbarOptions = customBubble;
              </xsl:otherwise>
            </xsl:choose>

            <xsl:choose>
              <xsl:when test="./options/controlLayer">
            customBubble.control.events.on({
                scope: this,
                activate: function(){
                    var layers = objGPWidget<xsl:value-of select='$pMapName'/>.getLayersByName(tmplLayerName);
                    for(var i=0; i&lt;layers.length; i++) {
                        layers[i].setVisibility(true);
                    }
                },
                deactivate: function(){
                    var layers = objGPWidget<xsl:value-of select='$pMapName'/>.getLayersByName(tmplLayerName);
                    for(var i=0; i&lt;layers.length; i++) {
                        layers[i].setVisibility(false);
                    }
                }
            });
              </xsl:when>
            </xsl:choose>
      }
      //});

    </script>
  </xsl:template>
  <!-- printWidgetExecution END  -->

  <!-- drawWidget START  -->
  <xsl:template name="templatepopup:drawWidget">
    <xsl:param name="pWidgetName" />
      objGPWidget<xsl:value-of select="$pWidgetName" />
  </xsl:template>
  <!-- drawWidget END  -->

  <!--
       Method: drawWidgets
         Add the objGPWidget<WidgetType>Container object to an other given
         container

       Properties:
         pContainer - objGPWidget<WidgetType>Container is added to this object
         WidgetType - The widget type
    -->
  <!-- drawWidgets START  -->
  <xsl:template name="templatepopup:drawWidgets">
    <xsl:param name="pContainer" />

    <xsl:variable name="WidgetType">
      <xsl:text>templatepopup</xsl:text>
    </xsl:variable>
  </xsl:template>
  <!-- drawWidgets END  -->

</xsl:stylesheet>
