GeoExt.ux.FilterBuilderSelector = Ext.extend(Ext.Panel, {

    /*
     * const: filter_button_text {String} Text in the filter button
     */
    filter_button_text : "Filter",
        
    /*
     * const: title {String} The default title for the panel
     */
    title : "Filter Builder",
    


    /**
     * APIProperty: filter
     * {OGCFilter} The filter created by selected options
     */
    filter : null,

    /**
     * APIProperty: wfsFilterBuilderButton (GeoExt.ux.WFSFilterBuilderButton) The
     * linked parent WFSFilterBuilderButton
     */
    wfsFilterBuilderButton : null,

    /**
     * APIProperty: GXPFilterBuilder
     * {gxp.FilterBuilder} The current filterbuilder showed
     */
    GXPFilterBuilder : null,
    


    /**
     * APIProperty: GXPFilterBuilder
     * {Combobox} The combobox that list all the layers avaiable
     */
    comboBoxLayerType : null,
    comboSelectedIndex : null,
    

    /**
     * APIProperty: featureConfigs
     * {Array} The configuration of all the resources used
     */
    featureConfigs: [],
    

    /**
     * Property: bodyStyle
     * {String} The default bodyStyle of the panel
     */
    bodyStyle:'padding:5px 5px 0',

    /**
     * APIProperty: featureConfigs
     * {Array} The width for the layer combobox
     */
    layerTypeComboBoxWidth: 300,

    initComponent : function() {

        //The button than enable to apply the filter
        this.bbar = [ "->", {
			xtype: 'button',
			iconCls: 'save',
            text : this.filter_button_text,
            handler : function() {
                if(!this.wfsFilterBuilderButton.autoFilter)
                    this.doFilter();
                this.wfsFilterBuilderButton.tabPanel.setActiveTab(1);
            },
            scope : this
        } ];
        GeoExt.ux.FilterBuilderSelector.superclass.initComponent.apply(this, arguments);
    },


    /** api: method[doFilter]
     */
    doFilter: function() {
        if (this.GXPFilterBuilder != null) {
            //Apply the filter and reload the store
            var selectedIndex = this.comboSelectedIndex;
            var store = this.featureConfigs[selectedIndex].store;
            var filter = this.GXPFilterBuilder.getFilter();

            this.setFilter(filter);
            store.load();
            this.fireEvent('filter', this);
        }
    },



    /** api: method[setFilter]
     *  :arg filter: ``OpenLayers.Filter`` Filter to be set on the WFS protocol.
     */
    setFilter: function(filter) {
        if (filter) {
            this.filter = filter;
        } else {
            this.filter = null;
        }
    },

    /** api: method[getFilter]
     *  :returns: ``OpenLayers.Filter``
     */
    getFilter: function() {
        return this.filter;
    },

    /** Method: clearFilterBuilder
     *  This method destroy the current filterBuilder and create a new, clean one.
     */
    clearFilterBuilder: function() {
        if(this.comboSelectedIndex != null)
        {
            this.removeAll(true);

            this.createFilterBuilder(this.comboSelectedIndex);

            this.add(this.fieldsetFilterBuilder);
            this.doLayout();
        }
    },

    /**
     * Method: changeFeatureType
     * This method destroy the current filterBuilder and create a new one
     */
    changeFeatureType : function(params) {
        this.removeAll(true);
		
        //Set comboSelectedIndex to current selected Index
        this.comboSelectedIndex = params.selectedIndex;

        this.createFilterBuilder(params.selectedIndex);

        this.add(this.fieldsetFilterBuilder);
        this.doLayout();
    },


    /**
     * Method: createFilterBuilder
     * This method create a new FilterBuilder
     */
    createFilterBuilder : function(selectedIndex) {
        var featureConfigs = this.featureConfigs[selectedIndex];
        var attribute = featureConfigs.attribute;
        
        //Remove all the fields than we don't want to view
        for (var i = 0; i < featureConfigs.ignoredFields.length; i++) {
            var attributeIndex = attribute.find("name", featureConfigs.ignoredFields[i]);
            if (attributeIndex != -1) {
                attribute.removeAt(attributeIndex);
            }
        }     
        
        this.GXPFilterBuilder = new gxp.FilterBuilder({
            allowedBuilderTypes : [ gxp.FilterBuilder.ANY_OF, gxp.FilterBuilder.ALL_OF, gxp.FilterBuilder.NONE_OF, gxp.FilterBuilder.NOT_ALL_OF ],
            builderTypeNames: this.filter_builder_type_names,
            preComboText: this.filter_builder_pre_combo_text,
            postComboText: this.filter_builder_post_combo_text,
            addConditionText: this.filter_builder_add_condition_text,
            style : "padding: 10px 0px 0px 0px",
            width : this.width,
            allowGroups : false,
            attributes : attribute
        });

        this.fieldsetFilterBuilder = new Ext.form.FieldSet({
            title : this.filter_fieldset_text,
            autoHeight : true,
            style: { padding: 10, marginTop: 10, margin:10 },
            items : [ this.GXPFilterBuilder ]
        });
    }
});
