<?php
/**
* ACL (Access Control List - liste de contrôle d'accès) qui utilise la library acl de borealis
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Pascal Martin 
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* ACL (Access Control List - liste de contrôle d'accès) qui utilise la library acl de borealis
* 
* @category   PHP 
* @package    GeoPrisma
* @subpackage ACL 
* @author     Pascal Martin 
*/ 
class org_geoprisma_acl_BorealisACL extends org_geoprisma_acl_ACL
{
    private static $s_objInstance = null;
    private static $s_strUsername = 'anonymous'; 
    private static $s_bCaching     = false;
    
    /**
    * Construit un instance de org_geoprisma_acl_BorealisACL
    * 
    * @return org_geoprisma_acl_BorealisACL
    */
    private function __construct()
    {
        // Constructeur privé pour forcer l'utilisation de getInstance (Singleton DP)
    }
    
    /**
    * Retourne un instance de org_geoprisma_acl_BorealisACL
    * Singleton DP
    * 
    * @return org_geoprisma_acl_BorealisACL
    */
    public static function getInstance()
    {
        if (is_null(self::$s_objInstance)) 
        {
            self::$s_objInstance = new org_geoprisma_acl_BorealisACL();
        }
        return self::$s_objInstance;
    }
    
    /**
    * Indique si nous somme autoriser a accéder à l'action de la ressource spécifier
    * 
    * @param org_geoprisma_resource_Resource $pobjResource Resource object
    * @param string                          $pstrAction   Nom de l'action
    * 
    * @return boolean
    */
    public function isAuthorized($pobjResource, $pstrAction)
    {
        $strResourceName = null;

        if ($pobjResource->getACLName() == "") 
        {
            $strResourceName = $pobjResource->getName();
        }
        else
        {
            $strResourceName = $pobjResource->getACLName();
        }

        if (self::$s_bCaching == true) 
        {
            if (!isset($_SESSION["gpAuthorized"])) 
            {
                $_SESSION["gpAuthorized"] = array();
            }

            if (!isset($_SESSION["gpAuthorized"][$strResourceName])) 
            {
                $_SESSION["gpAuthorized"][$strResourceName] = array();
            }

            if (!isset($_SESSION["gpAuthorized"][$strResourceName][$pstrAction])) 
            {
                $objAclResource = com_borealis_acl_object_Ressource::getByName($strResourceName);
                $objAclAction = com_borealis_acl_object_Action::getByName($pstrAction);

                $_SESSION["gpAuthorized"][$strResourceName][$pstrAction] = ($objAclResource !== null && $objAclAction !== null && com_borealis_acl_manager_ACLManager::isAuthorized(self::getUsername(), $objAclResource, $objAclAction));  
            }

            return $_SESSION["gpAuthorized"][$strResourceName][$pstrAction];
        }
        else
        {
            $objAclResource = com_borealis_acl_object_Ressource::getByName($strResourceName);
            $objAclAction = com_borealis_acl_object_Action::getByName($pstrAction);

            return ($objAclResource !== null && $objAclAction !== null && com_borealis_acl_manager_ACLManager::isAuthorized(self::getUsername(), $objAclResource, $objAclAction));  
        }
    }
    
    /**
    * Set le username du user présentement connecter
    * 
    * @param string $pstrUsername Nom d'utilisateur
    * 
    * @return void
    */
    public static function setUsername($pstrUsername)
    {
        self::$s_strUsername = $pstrUsername;
    }
    
    /**
    * Retourne le username du user présentement connecter
    *
    * @return string 
    */
    public static function getUsername()
    {
        return self::$s_strUsername;
    }
 
    /**
    * Permet de mettre en memoire (Session)
    * la matrice de l'ACL.
    * 
    * @param boolean $pbCaching Enabled Caching 
    * 
    * @return void
    */
    public static function setCaching($pbCaching)
    {
        self::$s_bCaching = $pbCaching;
    }
    
    /**
    * Retourne le mode de caching
    *
    * @return boolean 
    */
    public static function isCached()
    {
        return self::$s_bCaching;
    }
}
  
?>
