<?php
/**
* Return text based on language and domain name using the php gettext fonction
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Stephane Guillemette
* @author    Pascal Martin   
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Return text based on language and domain name using the php gettext fonction 
*  
* @category   PHP 
* @package    GeoPrisma
* @subpackage UI
* @author     Stephane Guillemette
* @author     Pascal Martin
*/      
  
class org_geoprisma_locale_GetTextLocale extends org_geoprisma_locale_Locale
{
    private static $s_objInstance = null;
 
    /**
    * Construit un instance de org_geoprisma_locale_GetTextLocale
    * 
    * @return org_geoprisma_locale_GetTextLocale
    */   
    private function __construct()
    {
        // Constructeur privé pour forcer l'utilisation de getInstance (Singleton DP)      
        $this->setLanguage($this->getDefaultLanguage());    
    }
    
    /**
    * Retourne un instance de org_geoprisma_locale_GetTextLocale
    * Singleton DP
    * 
    * @return org_geoprisma_locale_GetTextLocale
    */
    public static function getInstance()
    {
        if (is_null(self::$s_objInstance)) 
        {
            self::$s_objInstance = new org_geoprisma_locale_GetTextLocale();
        }
        return self::$s_objInstance;
    }
    
    /**
    * Set the current use langage for traduction (e.g. en_US , fr_CA)
    * 
    * @param string $pstrLanguage Language
    * 
    * @return void
    */
    public function setLanguage($pstrLanguage)
    {
        parent::setLanguage($pstrLanguage);    
        putenv("LANGUAGE=$pstrLanguage"); 
        setlocale(LC_ALL, $pstrLanguage.".UTF8"); 
    }
      
    /**
    * Return text based on domainName for right language
    * 
    * @param string $pstrMsg        Message Key
    * @param string $pstrDomainName Name of the 
    *
    * @return string 
    */  
    public function getTranslation($pstrMsg, $pstrDomainName)
    {        
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrDomainName); 

        bindtextdomain($pstrDomainName, org_geoprisma_SettingImpl::getLocaleDir());
        textdomain($pstrDomainName);

        bind_textdomain_codeset($pstrDomainName, "UTF-8");
        return _($pstrMsg);
    } 
}
?>
