<?php
/**
* Classe option de ressource ou de widget
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Pascal Martin 
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Classe option de ressource ou de widget
* 
* @category   PHP 
* @package    GeoPrisma
* @subpackage Option 
* @author     Pascal Martin 
*/ 
class org_geoprisma_option_Option extends org_geoprisma_ConfigElement
{
    private $m_strName = null;
    private $m_strValue = null;
    
    /**
    * Construit un instance de org_geoprisma_option_Option
    * 
    * @param string $pstrName  Option name
    * @param string $pstrValue Option value
    * 
    * @return org_geoprisma_option_Option
    */
    public function __construct($pstrName , $pstrValue) 
    {    
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrName);
        //com_borealis_foundation_util_Assert::assertIsString($pstrValue); 
        
        $this->m_strName = $pstrName;
        $this->m_strValue = $pstrValue;
    }

    /**
    * Option Name
    *
    * @return string
    */
    public function getName()
    {
        return $this->m_strName;   
    }
    
    /**
    * Option value
    *
    * @return string
    */
    public function getValue()
    {
        return $this->m_strValue;   
    }

    /**
    * Set option value
    *
    * @param string $pstrValue Option value
    *
    * @return string
    */
    public function setValue($pstrValue) 
    {
        $this->m_strValue = $pstrValue;
    }

    /**
    * Set option name
    *
    * @param string $pstrName Option name
    *
    * @return string
    */
    public function setName($pstrName) 
    {
        $this->m_strName = $pstrName;
    }
    
    /**
    *  Ajout l'option courant (this) dans le xml      
    * 
    * @param DOMElement  &$pobjDomElementOptions Noeud xml ou l'option doit être ajouter
    * @param DOMDocument &$pobjDomDocument       Document XMl ou le noeud xml datastore est ajouter, utiliser pour construire les noeuds
    * 
    * @return void
    */
    public function insertIntoXML(
        DOMElement &$pobjDomElementOptions, DOMDocument &$pobjDomDocument
    ) {
        $pobjDomElementOptions->appendChild(
            $this->getDomElements(
                $this->getName(), $this->getValue(), $pobjDomDocument
            )
        );
    }
}

?>
