<?php
/**
* Construit le bon type de feature server proxy selon le type de requete
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Pascal Martin 
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Construit le bon type de feature server proxy selon le type de requete
* 
* @category   PHP 
* @package    GeoPrisma
* @subpackage Proxy 
* @author     Pascal Martin 
*/  
class org_geoprisma_proxy_featureserver_FeatureServerProxyFactory
{
    /**
    * Return the good feature server proxy
    * 
    * @param org_geoprisma_service_FeatureServerService $pobjService Service
    * 
    * @return org_geoprisma_proxy_featureserver_FeatureServerGetCapabilityProxy
    */
    public static function getFeatureServerProxy(org_geoprisma_service_FeatureServerService $pobjService)
    {
        // Set default to read
        $objFeatureServerProxy = new org_geoprisma_proxy_featureserver_FeatureServerReadProxy($pobjService);
        
        if (self::isGetCapability()) 
        {    
            $objFeatureServerProxy = new org_geoprisma_proxy_featureserver_FeatureServerGetCapabilityProxy($pobjService);
        }
        elseif (self::isDelete())
        {
            $objFeatureServerProxy = new org_geoprisma_proxy_featureserver_FeatureServerDeleteProxy($pobjService);
        }
        elseif (self::isUpdate())
        {
            $objFeatureServerProxy = new org_geoprisma_proxy_featureserver_FeatureServerUpdateProxy($pobjService);
        }
        elseif (self::isCreate())        
        { 
            $objFeatureServerProxy = new org_geoprisma_proxy_featureserver_FeatureServerCreateProxy($pobjService);
        }    
   
        return $objFeatureServerProxy;
    }
    
    /**
    * Check if query is the type of getCapability | The layer is not specifield
    * 
    * @return bool
    */
    private static function isGetCapability()
    {
        $strLayer = org_geoprisma_proxy_featureserver_FeatureServerProxy::getLayer();
        return $strLayer == '';
    }
    
    /**
    * Check if the query is delete | Request Method = DELETE
    * 
    * @return bool 
    */
    private static function isDelete()
    {
        $iId = org_geoprisma_proxy_featureserver_FeatureServerProxy::getID();    
        return $iId != null && isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] == 'DELETE';    
    }
    
    /**
    * Check if the query is Create | Request Method = POST
    * 
    * @return bool 
    */
    private static function isCreate()
    {    
        $iId = org_geoprisma_proxy_featureserver_FeatureServerProxy::getID();             
        return $iId == null && isset($GLOBALS['HTTP_RAW_POST_DATA']) != null && $GLOBALS['HTTP_RAW_POST_DATA'] != '' && isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] == 'POST';    
    }
    
    /**
    * Check if the query is delete
    * 
    * @return bool 
    */
    private static function isUpdate()
    {
        $iId = org_geoprisma_proxy_featureserver_FeatureServerProxy::getID();
        return $iId != null && isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] == 'PUT';
    }
}
?>
