<?php
/**
* Class Proxy de type feature server
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Julien-Samuel Lacroix 
* @copyright 2010, Mapgears inc
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Class Proxy de type feature server 
* 
* @category   PHP 
* @package    GeoPrisma
* @subpackage Proxy 
* @author     Julien-Samuel Lacroix
*/   
abstract class org_geoprisma_proxy_file_FileProxy extends org_geoprisma_proxy_Proxy
{
    /**
    * Return Layer
    * 
    * @return string
    */
    public function getLayer()
    {
        if (isset($_REQUEST['path']) && $_REQUEST['path']) 
        {
            return preg_replace('/^root\/?/', '', $_REQUEST['path']);
        }
        return '';        
    }
    
    /**
    * Retourne la liste de layer accèder par la query
    * 
    * @return ArrayObject
    */
    public function getLayers()
    {
        $objArrayLayers = new ArrayObject();
        $strLayer = $this->getLayer();
        if ($strLayer != "") 
        {
            $objArrayLayers->append($strLayer);
        }
        return $objArrayLayers;    
    }

    /**
    * Validate the 'layers' being accessed by the query.  Each layer must be
    *     present in one of the specified resource datastore using a specified
    *     service.
    * 
    * @param org_geoprisma_service_Service $pobjService        The service to
    *                                                          use for 
    *                                                          validation.
    *                                                          Defaults to
    *                                                          the proxy
    *                                                          service.
    * @param ArrayObject                   $pobjArrayResources ArrayObject of
    *                                                          resource objects.
    *                                                          Defaults to the
    *                                                          proxy resources.
    * @param ArrayObject                   $pobjArrayLayers    ArrayObject of
    *                                                          layers to
    *                                                          validate.
    *                                                          Defaults to the
    *                                                          layers returned
    *                                                          by the proxy
    *                                                          'getLayers'
    *                                                          method. 
    *
    * @return void    
    */
    public function validateLayersFromRequest(
        $pobjService=null,
        $pobjArrayResources=null,
        $pobjArrayLayers=null
    ) {
        $objService = ($pobjService === null) ? $this->getService() : $pobjService;
        $objArrayResources = ($pobjArrayResources === null) ? $this->getResources() : $pobjArrayResources;
        $objArrayLayers = ($pobjArrayLayers === null) ? $this->getLayers() : $pobjArrayLayers;

        $bAllAuthorized = true;
        foreach ($objArrayLayers as $strLayer) 
        {
            $bIsAuthorized = false;
            foreach ($objArrayResources as $objResource) 
            {
                $objDatastore = $objResource->getDatastore($objService);
                if (self::isAuthorizedLayer($objDatastore, $strLayer)) 
                {
                    $bIsAuthorized = true;
                    break;
                }
            }
            if (!$bIsAuthorized) 
            {
                $bAllAuthorized = false;
                break;
            }
        }

        if (!$bAllAuthorized) 
        {
            throw new Exception('Not Authorized by Datastore layer');    
        }
    }


    /**
    * Validate if the layer is accessible in this datastore.
    * 
    * @param org_geoprisma_datastore_Datastore $pobjDatastore Datastore
    * @param String                            $pstrLayer     Layer name
    *
    * @return Boolean
    */
    private static function isAuthorizedLayer($pobjDatastore, $pstrLayer)
    {
        $objArrayDSLayers = $pobjDatastore->getLayers();

        $bAuthorized = false;
        foreach ($objArrayDSLayers as $strDSLayer) 
        {
            if (substr($strDSLayer, -1) == '/') 
            {
                $strDSLayer = substr($strDSLayer, 0, -1);
            }

            $objArrayDSPath = explode('/', $strDSLayer);
            $objArrayLayerPath = explode('/', $pstrLayer);
            $iNumDSPathNode = count($objArrayDSPath);
            $iNumLayerPathNode = count($objArrayLayerPath);
            $iNumPathNode = min($iNumDSPathNode, $iNumLayerPathNode);
            for ($iIter=0; $iIter<$iNumPathNode; $iIter++) 
            {
                if ($objArrayDSPath[$iIter] != $objArrayLayerPath[$iIter]) 
                {
                    break;
                }

                if (($iIter+1) >= $iNumPathNode) 
                {
                    $bAuthorized = true;
                }
            }

            if ($bAuthorized) 
            {
                break;
            }
        }

        return $bAuthorized;
    }
}
  
?>
