<?php
/**
* Proxy of HttpRequest type
*
* PHP versions 5
*
* @category  PHP
* @package   GeoPrisma
* @author    Frédérick Gagnon
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Proxy of HttpRequest type
* 
* @category   PHP 
* @package    GeoPrisma
* @subpackage Proxy 
* @author     Frédérick Gagnon
*/     
class org_geoprisma_proxy_httprequest_HttpRequestProxy extends org_geoprisma_proxy_Proxy
{
    private $m_strRequestName = null;
    private $m_objArrayAvailableRequestsActions = array();

    /**
    * Creates a new instance of org_geoprisma_proxy_httprequest_HttpRequestProxy
    *
    * @param array $pobjService Service object
    * @param array $pobjRequest Request array
    *
    * @return org_geoprisma_proxy_httprequest_HttpRequestProxy
    */
    public function __construct($pobjService, $pobjRequest=null)
    {
        $pobjRequest = !is_null($pobjRequest) ? $pobjRequest : $_REQUEST;
        
        if (!isset($pobjRequest['REQUEST']))
        {
            throw new Exception("REQUEST param is missing");
        }

        $this->m_strRequestName = (string)$pobjRequest['REQUEST'];

        foreach ($pobjService->m_objArrayCreateHttpRequests as $strAvailableRequest)
        {
            $this->m_objArrayAvailableRequestsActions[$strAvailableRequest] = self::CRUD_CREATE;
        }

        foreach ($pobjService->m_objArrayReadHttpRequests as $strAvailableRequest)
        {
            $this->m_objArrayAvailableRequestsActions[$strAvailableRequest] = self::CRUD_READ;
        }

        foreach ($pobjService->m_objArrayUpdateHttpRequests as $strAvailableRequest)
        {
            $this->m_objArrayAvailableRequestsActions[$strAvailableRequest] = self::CRUD_UPDATE;
        }

        foreach ($pobjService->m_objArrayDeleteHttpRequests as $strAvailableRequest)
        {
            $this->m_objArrayAvailableRequestsActions[$strAvailableRequest] = self::CRUD_DELETE;
        }

        if (empty($this->m_objArrayAvailableRequestsActions))
        {
            throw new Exception("Service has no available request");
        }

        if (!isset($this->m_objArrayAvailableRequestsActions[$this->m_strRequestName]))
        {
            throw new Exception("Request has no available action");
        }

        parent::__construct($pobjService);
    }
    /**
    * Returns the name of the action done by this proxy (Create / Read / Update / Delete)
    *                                   
    * @return string
    */
    public function getAction()
    {
        return $this->m_objArrayAvailableRequestsActions[$this->m_strRequestName];
    }

    /**
    * Foward the call end return the result
    * 
    * @return void
    */
    public function process()
    {
        $objArrayResources = $this->getResources();
        $objArrayLayers = $objArrayResources[0]->getDatastore($this->getService())->getLayers();
        $strAdditionalParams['REQUEST_DATA'] = $objArrayLayers[0];

        ob_start();
        $objCurl = curl_init();
        curl_setopt($objCurl, CURLOPT_URL, self::addParam($this->getService()->getSource(), $strAdditionalParams));
        curl_setopt($objCurl, CURLOPT_POST, true);
        curl_setopt($objCurl, CURLOPT_POSTFIELDS, file_get_contents('php://input'));
        curl_setopt($objCurl, CURLOPT_HTTPHEADER, array('Content-Type: application/x-www-form-urlencoded'));

        curl_exec($objCurl);

        $objArrayInfo = curl_getinfo($objCurl);
        curl_close($objCurl);

        header("Content-type: ".$objArrayInfo['content_type']);

        ob_end_flush();
    }
    
    /**
    * Returns the list of layers accessible by this proxy
    *
    * @return ArrayObject
    */
    public function getLayers()
    {
        return new ArrayObject();
    }


    /**
    * Add received GET parameters to an URL
    *
    * @param string $pstrUrl              Url
    * @param array  $pstrAdditionalParams Params array
    *
    * @return string
    */
    static public function addParam($pstrUrl, $pstrAdditionalParams)
    {
        if (strpos($pstrUrl, '?') === false)
        {
            return $pstrUrl."?".http_build_query(array_merge(self::getRequestParams(), $pstrAdditionalParams));
        }
        else
        {
            return $pstrUrl."&".http_build_query(array_merge(self::getRequestParams(), $pstrAdditionalParams));
        }
    }
}
?>
