<?php
/**
* Class Proxy de type WPS
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Pascal Martin 
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Class Proxy de type WPS 
* 
* @category   PHP 
* @package    GeoPrisma
* @subpackage Proxy 
* @author     Pascal Martin 
*/     
class org_geoprisma_proxy_wps_WPSProxy extends org_geoprisma_proxy_Proxy
{
    /**
    * Retourne le nom de l'action réaliser par le proxy (Create - Read - Update - Delete)
    *                                   
    * @return string
    */
    public function getAction()
    {
        return self::CRUD_READ;    
    }

    /**
    * Foward the call end return the result
    * 
    * @return void
    */
    public function process()
    {
        ob_start();
        $objCurl = curl_init($this->addParam($this->getService()->getSource()));
        curl_exec($objCurl);
        $objArrayInfo = curl_getinfo($objCurl);
        curl_close($objCurl);

        header("Content-type: $objArrayInfo[content_type]");

        ob_end_flush(); 
    }
    
    /**
    * Retourne la liste de layer accèder par la query
    * 
    * @return ArrayObject
    */
    public function getLayers()
    {
        $objArrayLayer = new ArrayObject();
        foreach ($_GET as $strKey => $strValue) 
        {
            if (strtoupper($strKey) == "IDENTIFIER") 
            {
                $objArrayLayer = new ArrayObject(explode(',', $_GET[$strKey]));
            }
        }
        return $objArrayLayer;         
    }

    /**
    * Validate the resources being accessed by the query by simply loading the
    *     datastore of a specified service.
    * 
    * @param org_geoprisma_service_Service $pobjService        The service to
    *                                                          use for 
    *                                                          validation.
    *                                                          Defaults to
    *                                                          the proxy
    *                                                          service.
    * @param ArrayObject                   $pobjArrayResources ArrayObject of
    *                                                          resource objects
    *                                                          to validate.
    *                                                          Defaults to the
    *                                                          proxy resources.
    *
    * @return void    
    */
    public function validateResourcesFromRequest(
        $pobjService=null,
        $pobjArrayResources=null
    ) {

        // Normal check for the current process
        parent::validateResourcesFromRequest($pobjService, $pobjArrayResources);


        // Then check all services we connect to
        $objConfig = org_geoprisma_config_ConfigFactory::getConfig();
        $objDataInput = $this->getNestedURLParts('DataInputs');

        foreach($objDataInput as $szURL => $objQueryString)
        {
            if(!$objConfig->isProxyURL($szURL) && !$objConfig->isServiceHost($szURL))
            {
                continue;
            }

            if(!isset($objQueryString['osmservice']) || !isset($objQueryString['osmresource']))
            {
                throw new Exception('Not Authorized by Config - Nested URL');   
            }

            $objService = $objConfig->getService($objQueryString['osmservice']);
            $objArrayResources = array();
            foreach($objQueryString['osmresource'] as $strResourceName)
            {
                $objArrayResources[] = $objConfig->getResource($strResourceName);
            }

            parent::validateResourceFromRequest($objService, $objArrayResources);
        }
    }

    /**
    * Validate the 'layers' being accessed by the query.  Each layer must be
    *     present in one of the specified resource datastore using a specified
    *     service.
    * 
    * @param org_geoprisma_service_Service $pobjService        The service to
    *                                                          use for 
    *                                                          validation.
    *                                                          Defaults to
    *                                                          the proxy
    *                                                          service.
    * @param ArrayObject                   $pobjArrayResources ArrayObject of
    *                                                          resource objects.
    *                                                          Defaults to the
    *                                                          proxy resources.
    * @param ArrayObject                   $pobjArrayLayers    ArrayObject of
    *                                                          layers to
    *                                                          validate.
    *                                                          Defaults to the
    *                                                          layers returned
    *                                                          by the proxy
    *                                                          'getLayers'
    *                                                          method. 
    *
    * @return void    
    */
    public function validateLayersFromRequest(
        $pobjService=null,
        $pobjArrayResources=null,
        $pobjArrayLayers=null
    ) {

        parent::validateLayersFromRequest($pobjService, $pobjArrayResources, $pobjArrayLayers);


        // Then check all services we connect to
        $objConfig = org_geoprisma_config_ConfigFactory::getConfig();
        $objDataInput = $this->getNestedURLParts('DataInputs');

        foreach($objDataInput as $szURL => $objQueryString)
        {
            if(!$objConfig->isProxyURL($szURL) && !$objConfig->isServiceHost($szURL))
            {
                continue;
            }

            if(!isset($objQueryString['osmservice']) || !isset($objQueryString['osmresource']))
            {
                throw new Exception('Not Authorized by Config - Nested URL');   
            }

            $objService = $objConfig->getService($objQueryString['osmservice']);
            $objArrayResources = array();
            foreach($objQueryString['osmresource'] as $strResourceName)
            {
                $objArrayResources[] = $objConfig->getResource($strResourceName);
            }
            if(isset($objQueryString['layers']))
                $objArrayLayers = explode(',', $objQueryString['layers']);
            if(isset($objQueryString['typename']))
                $objArrayLayers[] = $objQueryString['typename'];

            parent::validateLayersFromRequest($objService, $objArrayResources, $objArrayLayers);
        }
    }

    public function getNestedURLParts($strParam)
    {
        $objReturn = array();

        foreach ($_REQUEST as $strKey => $strValue) 
        {
            if (strtoupper($strKey) == strtoupper($strParam)) 
            {
                $objQueryInput = array();
                $objInputs = explode('@', $strValue);
                foreach($objInputs as $strInput)
                {
                    $objInputKey = substr($strInput, 0, strpos($strInput, '='));
                    $objInputValue = substr($strInput, strpos($strInput,'=')+1);
                    $objQueryInput[strtolower($objInputKey)] = $objInputValue;
                }

                if(isset($objQueryInput['xlink:href']) && $objQueryInput['xlink:href'])
                {
                    $szURL = urldecode($objQueryInput['xlink:href']);

                    $objGET = array();
                    $objURLParts = parse_url($szURL);
                    $objQueryString = explode('&', $objURLParts['query']);
                    foreach ($objQueryString as $strQueryPart)
                    {
                        $objQueryPart = explode('=', $strQueryPart);
                        if(substr($objQueryPart[0], -2) == '[]')
                            $objGET[substr($objQueryPart[0], 0, -2)][] = $objQueryPart[1];
                        else
                            $objGET[$objQueryPart[0]] = $objQueryPart[1];
                    }

                    $objReturn[$szURL] = $objGET;
                }
            }
        }

        return $objReturn;
    }
}
  
?>
