<?php
/**
* Service de type feature server     
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Pascal Martin 
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Service de type feature server 
* 
* @category   PHP 
* @package    GeoPrisma
* @subpackage Service 
* @author     Pascal Martin 
*/  
class org_geoprisma_service_FeatureServerService extends org_geoprisma_service_Service
{
    const FEATURESERVER_SERVICE = 'featureserver';
    const TYPE = 'featureserver';
    const TYPE_ID = 3;

    /**
    * Construit un instance de org_geoprisma_service_FeatureServerService
    * 
    * @param array $pobjArray Config
    * 
    * @return org_geoprisma_service_FeatureServerService
    */
    public function __construct($pobjArray) 
    {
        if (isset($pobjArray['id'])) 
        {
            $strName = (string)$pobjArray['id'];
        }
        else
        {
            $strName = (string)$pobjArray['name'];
        }

        $strSource = (string)$pobjArray['source'];
    
        parent::__construct($strName, $strSource, self::TYPE, $pobjArray);
    }

    /**
    * Return the OpenLayers.Layer default options using this type of service.
    * 
    * @param org_geoprisma_config_Config &$pobjConfig Config object
    *
    * @return array 
    */
    public function getDefaultLayerOptions(&$pobjConfig)
    {
        return array(
            'visibility' => 'false',
            'extractAttributes' => 'true'
        );
    }
    
    /**
    *  Ajout le service courant (this) dans le xml     
    * 
    * @param DOMElement  &$pobjDomElementServices Noeud xml ou le service doit être ajouter
    * @param DOMDocument &$pobjDomDocument        Document XMl ou le noeud xml datastore est ajouter, utiliser pour construire les noeuds
    * 
    * @return void
    */
    public function insertIntoXML(DOMElement &$pobjDomElementServices, DOMDocument &$pobjDomDocument)
    {
        $objDomElementService = $pobjDomDocument->createElement('service'); 
        $pobjDomElementServices->appendChild($objDomElementService);        
        $objDomElementType = $pobjDomDocument->createElement('type', self::FEATURESERVER_SERVICE);
        $objDomElementName = $pobjDomDocument->createElement('name', $this->getName());
        $objDomElementService->appendChild($objDomElementType);
        $objDomElementService->appendChild($objDomElementName);

        // options node
        $objDomElementService->appendChild(
            $this->getDomElements(
                'options', $this->getOptions(), $pobjDomDocument
            )
        );
    }

    /**
    * Build and execute a get request given a specific layername.
    * 
    * @param string $pstrLayerName The layer name to use in the request.
    * @param string $pstrValue     Condition value for the request
    * 
    * @return string
    */
    public function getFeature($pstrLayerName, $pstrValue)
    {
        $strFormat = "geojson";
        $objCurl = curl_init(
            $this->getSource()."/".$pstrLayerName."/".$pstrValue.".".$strFormat
        );
        curl_setopt($objCurl, CURLOPT_RETURNTRANSFER, 1);
        $strContents = curl_exec($objCurl);
        curl_close($objCurl);
        ob_clean();

        return $strContents;
    }
}
  
?>
