<?php
/**
* File service type
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Alexandre Dube 
* @copyright 2010, Centre de Geomatique du Quebec
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* File service type
* 
* @category   PHP 
* @package    GeoPrisma
* @subpackage Service 
* @author     Alexandre Dube 
*/
class org_geoprisma_service_FileService extends org_geoprisma_service_Service
{
    const WMS_SERVICE = 'file';
    const TYPE = 'file';
    const TYPE_ID = 8;

    /**
    * Creates a new instance of org_geoprisma_service_FileService
    * 
    * @param array $pobjArray Config array
    * 
    * @return org_geoprisma_service_FileService
    */
    public function __construct($pobjArray) 
    {
        if (isset($pobjArray['id'])) 
        {
            $strName = (string)$pobjArray['id'];
        }
        else
        {
            $strName = (string)$pobjArray['name'];
        }

        $strSource = (string)$pobjArray['source'];
        
        parent::__construct($strName, $strSource, self::TYPE, $pobjArray);
    }

    /**
    * Return the OpenLayers.Layer default options using this type of service.
    * Since this service won't create any layers, it returns an empty array.
    * 
    * @param org_geoprisma_config_Config &$pobjConfig Config object
    *
    * @return array 
    */
    public function getDefaultLayerOptions(&$pobjConfig)
    {
        return array();
    }
    
    /**
    * Add current service in XML document.
    * 
    * @param DOMElement  &$pobjDomElementServices XML node where this service
    *                                             must be added
    * @param DOMDocument &$pobjDomDocument        DOMDocument XMl used to create
    *                                             new nodes.
    * 
    * @return void
    */
    public function insertIntoXML(
        DOMElement &$pobjDomElementServices,
        DOMDocument &$pobjDomDocument
    ) {
        $objDomElementService = $pobjDomDocument->createElement('service'); 
        $pobjDomElementServices->appendChild($objDomElementService);        
        $objDomElementType = $pobjDomDocument->createElement('type', self::WMS_SERVICE);
        $objDomElementName = $pobjDomDocument->createElement('name', $this->getName());
        $objDomElementService->appendChild($objDomElementType);
        $objDomElementService->appendChild($objDomElementName); 

        // options node
        $objDomElementService->appendChild(
            $this->getDomElements(
                'options', $this->getOptions(), $pobjDomDocument
            )
        );
    }
}
  
?>
