<?php
/**
* Run the layout with the config file
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Pascal Martin 
* @copyright 2009, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Run the layout with the config file
*  
* @category   PHP 
* @package    GeoPrisma
* @subpackage Exception
* @author     Stephane Guillemette
* @author     Pascal Martin
*/
class org_geoprisma_uirender_UI
{
    private $m_objLayout = null;
    
    /**
    * Construit un instance de org_geoprisma_uirender_UI
    *  
    * @param string $pstrLayoutName Layout
    *  
    * @return org_geoprisma_uirender_UI
    */
    public function __construct($pstrLayoutName)
    {
        com_borealis_foundation_util_Assert::assertIsNotEmptyString($pstrLayoutName);
            
        $this->m_objLayout = org_geoprisma_config_ConfigFactory::getConfig()->getLayout($pstrLayoutName);        
    }
    
    /**
    * Call layout with the config file
    * 
    * @param array $pobjArrayParameters Extract param to add in xslt processor
    *
    * @return string
    */
    public function render($pobjArrayParameters = null)
    {
        $strResult = ""; 
        $objLayout = $this->m_objLayout;
        
        $objDomDocumentLayout = new DOMDocument();
        $objDomDocumentLayout->load(org_geoprisma_SettingImpl::getTemplateDir().'/'.$objLayout->getFile());
        
        $objXSLTProcessor = new XSLTProcessor(); 
        $objXSLTProcessor->importStylesheet($objDomDocumentLayout);
        $objXSLTProcessor->registerPHPFunctions();

        $objXSLTProcessor->setParameter('', 'proxyurl', org_geoprisma_uirender_utils_Proxy::getProxyURL());        
        $objXSLTProcessor->setParameter('', 'g_proxy_url_aliases', org_geoprisma_uirender_utils_Proxy::getProxyURLAliases());
        $objXSLTProcessor->setParameter('', 'drawmode', $objLayout->getDrawMode());
        
        $objXSLTProcessor->setParameter('', 'g_widgets_dir', org_geoprisma_SettingImpl::getWidgetDir());
        $objXSLTProcessor->setParameter('', 'g_lib_url', org_geoprisma_SettingImpl::getLibUrl());
        $objXSLTProcessor->setParameter('', 'g_template_url', org_geoprisma_SettingImpl::getTemplateUrl());
        $objXSLTProcessor->setParameter('', 'g_widgets_url', org_geoprisma_SettingImpl::getWidgetUrl());
        $objXSLTProcessor->setParameter('', 'g_locale', org_geoprisma_locale_LocaleFactory::getLocale()->getLanguage());
        $objXSLTProcessor->setParameter('', 'g_url_separator', org_geoprisma_SettingImpl::getURLSeparator());
         
        if ($pobjArrayParameters != null) 
        {
            foreach ($pobjArrayParameters as $objArrayParameter)
            {
                $objXSLTProcessor->setParameter('', $objArrayParameter['key'], $objArrayParameter['value']);
            }
        }
         
        return $objXSLTProcessor->transformToXML(org_geoprisma_config_ConfigFactory::getConfig()->getDomDocument());   
    }
    
    /**
    * Return the eval result 
    * 
    * @param string $pstrPhpCode php code to evaluate
    * @param bool   $pbInString  php code need to be in string 
    * 
    * @return mixed
    */
    public static function getValueFrom($pstrPhpCode, $pbInString = true)
    {
        $strResult = '';
        
        if ($pbInString) 
        {
            eval("\$strResult = \"$pstrPhpCode\";");
        }
        else
        {
            $strResult = eval($pstrPhpCode);    
        }
        
        if (!is_numeric($strResult) && $strResult != 'true' && $strResult != 'false') 
        {
            $strResult = org_geoprisma_locale_Locale::jsEncode($strResult);           
        }
        
        return $strResult;
    }
}
